@@ -145,6 +145,15 @@ void LineEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& ou
 	line_->push_back(PaperPoint(x+0.5, y));
 	out.push_back(line_);
 }
+void RainbowEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& out)
+{
+	double x = point.x();
+	double y = point.y();
+
+	line_->push_back(PaperPoint(x-0.5, y+0.5));
+	line_->push_back(PaperPoint(x+0.5, y+0.5));
+	out.push_back(line_);
+}
 void LineEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer& out)
 {
 	double x = point.x();
@@ -204,14 +213,18 @@ void LegendVisitor::build()
 		legend->push_back(titlePosition_);
 		legend_->push_back(legend);
 	}
-	
-	if ( use_min_ ) {
-		front()->userText(use_min_text_);
-	}
-	if ( use_max_ ) {
-		back()->userText(use_max_text_);
-	}
 
+	if ( !empty() ) {
+		if ( use_min_ ) {
+			front()->userText(use_min_text_);
+		}
+		if ( use_max_ ) {
+			back()->userText(use_max_text_);
+		}
+	
+		back()->units(units_text_);
+	}
+	
 	for(vector<LegendEntry*>::const_iterator entry = begin(); entry != end(); ++entry)
 	{
 		(*entry)->width(text_width_);
@@ -234,7 +247,7 @@ void LegendVisitor::build()
 				user = utext;
 			else
 				user = ( label != lines_.end() ) ? *label: "";
-			string automatic = (*entry)->label();
+			string automatic = (*entry)->label() + (*entry)->units();
 
 			if ( composition == compositions_.end() )
 			{
@@ -1259,9 +1272,6 @@ void SimpleSymbolEntry::set(const PaperPoint& point, BasicGraphicsObjectContaine
 }
 
 
-
-
-
 const string& LegendEntry::label() const
 {
 	if ( !label_.empty() || !fromto_)
@@ -1407,3 +1417,4 @@ BoxEntry::~BoxEntry() {} //{ delete box_; }
 ArrowEntry::~ArrowEntry() {} //{ delete arrow_; }
 DoubleLineEntry::~DoubleLineEntry() {} //{ { delete line1_; delete line2_; }
 LineEntry::~LineEntry() {} //{ delete line_;}
+RainbowEntry::~RainbowEntry() {} //{ delete line_;}
\ No newline at end of file
