@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file Data.h
     \brief Definition of the Abstract template class Data.
@@ -72,7 +64,7 @@ public:
 class Data: public MetviewIcon{
 
 public:
-	Data(): name_("no_name"), binning_(0), dimension_(1), valid_(true) {}
+	Data(): name_("no_name"), binning_(0), dimension_(1), valid_(true), thinningFactor_(1) {}
 	virtual ~Data() { if ( binning_ ) delete binning_; }
     //! Method to access the data as a matrix Used by pcont action routine
     virtual MatrixHandler& matrix() { throw MethodNotYetImplemented("Data::matrix"); }
@@ -110,8 +102,8 @@ public:
 
     virtual void customisedPoints(const AutomaticThinningMethod&, const Transformation& transformation, const std::set<string>& need , CustomisedPointsList& out)
            { customisedPoints(transformation, need, out, false); }
-    virtual void customisedPoints(const BasicThinningMethod&, const Transformation& transformation, const std::set<string>& need , CustomisedPointsList& out) 
-             { customisedPoints(transformation, need, out, false); }
+    virtual void customisedPoints(const BasicThinningMethod& thinning, const Transformation& transformation, const std::set<string>& need , CustomisedPointsList& out)
+             { thinningFactor_ = thinning.factor(); customisedPoints(transformation, need, out, false); }
     virtual void visit(TextVisitor&) {}
     virtual void visit(LegendVisitor&) {}
     virtual void visit(AnimationRules&) {}
@@ -158,6 +150,7 @@ protected:
      int dimension_;
      int index_;
      bool valid_;
+     int thinningFactor_;
      static int uniqueOwnerId_; // Metview usage for overlay control
 
  	 DateDescription timeStamp_;
