@@ -1,22 +1,12 @@
-/******************************** LICENSE ********************************
-
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
- 
- Licensed under the Apache License, Version 2.0 (the "License"); 
- you may not use this file except in compliance with the License. 
- You may obtain a copy of the License at 
- 
- 	http://www.apache.org/licenses/LICENSE-2.0
- 
- Unless required by applicable law or agreedto in writing, software
- distributed under the License is distributed on an "AS IS" BASIS, 
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
- See the License for the specific language governing permissions and 
- limitations under the License.
-
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file PolarStereographicProjection.cc
     \brief Implementation of PolarStereographicProjection.
@@ -125,7 +115,7 @@ PaperPoint PolarStereographicProjection::operator()(const UserPoint& point)  con
 	TeCoord2D geo = TeCoord2D(point.x()*TeCDR, point.y()*TeCDR);
 	TeCoord2D xy = projection_->LL2PC(geo);
 
-	return PaperPoint(xy.x(), xy.y(), point.value(), point.missing(), point.border());
+	return PaperPoint(xy.x(), xy.y(), point.value(), point.missing(), point.border(), 0, point.name());
 }
 
 
@@ -868,7 +858,7 @@ void PolarStereographicProjection::coastSetting(map<string, string>& setting, do
 	setting["boundaries"] = resol + "/ne_" + resol + "_admin_0_boundary_lines_land";
 	
 	//! \note Administraive borders hardcoded to 10m resolution (low res version do not contain all info)
-	setting["administrative_boundaries"] = "10m/10m_admin_1_states_provinces";
+	setting["administrative_boundaries"] = "10m/ne_10m_admin_1_states_provinces";
 
 	MagLog::dev() << "GeoRectangularProjection::coastSetting[" << abswidth << ", " << absheight << "]->" <<  ratio << " resol: "<<resol<< endl;
 }
