@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file Polyline.cc
     \brief Implementation of polyline graphics class (template).
@@ -28,8 +20,6 @@
 */
 #include "Polyline.h"
 #include "Transformation.h"
-#include "TeCoord2D.h"
-#include "TeGeometryAlgorithms.h"
 
 
 using namespace magics;
@@ -75,7 +65,7 @@ void Polyline::print(ostream& out) const
 {
 	out << "Polyline[";
 	out << ", nb_points = " << this->size();
-	  if ( this->size() < 25 ) {
+	  if ( this->size() < 1000 ) {
             out << " Outer [";
             string sep = "";
 	    const unsigned int nb = size();
@@ -146,6 +136,7 @@ void Polyline::hole(Holes::const_iterator hole, vector<double>& x, vector<double
 
 void Polyline::hole(Holes::const_iterator hole, Polyline& poly) const
 {
+
 	for (deque<PaperPoint>::const_iterator h = hole->begin(); h != hole->end(); ++h) {
 		poly.push_back(*h);
 	}
