@@ -1,22 +1,12 @@
-/******************************** LICENSE ********************************
-
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
- 
- Licensed under the Apache License, Version 2.0 (the "License"); 
- you may not use this file except in compliance with the License. 
- You may obtain a copy of the License at 
- 
- 	http://www.apache.org/licenses/LICENSE-2.0
- 
- Unless required by applicable law or agreed to in writing, software 
- distributed under the License is distributed on an "AS IS" BASIS, 
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
- See the License for the specific language governing permissions and 
- limitations under the License.
-
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file Proj4Projection.cc
     \brief Implementation of Proj4Projection.
@@ -327,7 +317,7 @@ PaperPoint Proj4Projection::operator()(const UserPoint& point)  const
 		MagLog::debug() << pj_strerrno(error) << " for " << point << endl;
 		return PaperPoint(-1000000, -10000000);
 	}
-	return PaperPoint(x, y, point.value_, point.missing());	               
+	return PaperPoint(x, y, point.value_, point.missing(), point.border(), 0, point.name());
 }
 
 PaperPoint Proj4Projection::operator()(const PaperPoint& point)  const
