@@ -1,15 +1,12 @@
-
-/******************************** LICENSE ********************************
-
-  Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF) 
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 // File Transformation.cc
 // Magics Team - ECMWF 2004
@@ -36,7 +33,7 @@ Transformation::Transformation() :
 	dataMaxX_(-std::numeric_limits<double>::max()),
 	dataMinY_(std::numeric_limits<double>::max()),
 	dataMaxY_(-std::numeric_limits<double>::min()),
-	topAxis_(true), xTile_(0), yTile_(0)
+	topAxis_(true), xTile_(0), yTile_(0), zoomLevel_(0)
 {
 	userEnveloppe_ = new Polyline();
 	PCEnveloppe_ = new Polyline();
@@ -447,11 +444,61 @@ void Transformation::operator()(const Polyline& from, BasicGraphicsObjectContain
 	catch (...) {
 		MagLog::warning() << "error clipping->line ignored" << endl;
 	}
+}
+
+void Transformation::operator()(const Polyline& from, vector<Polyline*>& out) const
+{
+	if (from.empty())
+		return;
+	PaperPoint ll(getMinPCX(), getMinPCY());
+	PaperPoint ur(getMaxPCX(), getMaxPCY());
+	boost::geometry::model::box<PaperPoint> box(ll, ur);
+	boost::geometry::correct(box);
 
 
 
 
+	vector<deque<PaperPoint> > holes;
+	vector<Polyline*> forholes;
 
+
+	try {
+		vector<vector<PaperPoint> > lines;
+		//line.reserve( from.size());
+		lines.push_back(vector<PaperPoint>());
+		for (unsigned i = 0; i < from.size(); i++) {
+			lines.back().push_back(from.get(i));
+
+		}
+		for ( Polyline::Holes::const_iterator hole = from.beginHoles(); hole != from.endHoles(); ++hole) {
+			Polyline poly;
+			from.hole(hole, poly);
+			lines.push_back(vector<PaperPoint>());
+			for (unsigned i = 0; i < poly.size(); i++) {
+				lines.back().push_back(poly.get(i));
+			}
+		}
+
+		for (vector<vector<PaperPoint> >::iterator line = lines.begin(); line != lines.end(); ++line) {
+			vector<vector<PaperPoint> > result;
+			boost::geometry::correct(*line);
+			boost::geometry::intersection(box, *line, result);
+
+			// Now we feed the graphic container!
+			for (vector<vector<PaperPoint> >::iterator l = result.begin(); l != result.end(); l++)
+			{
+				Polyline* poly = new Polyline();
+				for (vector<PaperPoint>::iterator point = l->begin(); point != l->end(); ++point)
+					poly->push_back(*point);
+				if ( !poly->empty() )
+					out.push_back(poly);
+			}
+		}
+	}
+
+	catch (...) {
+		MagLog::warning() << "error clipping->line ignored" << endl;
+	}
 }
 
 
