@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file NetcdfGeoMatrixInterpretor.cc
     \brief Implementation of the Template class NetcdfGeoMatrixInterpretor.
@@ -90,9 +82,8 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** data)
 			netcdf.get(field_, data, first, last);
 			int i = 0;
 			for (vector<double>::iterator d = data.begin(); d != data.end(); ++d ) {
-				if ( !isnan(*d) ) {
+				if ( !std::isnan(*d) ) {
 					matrix_->push_back(*d);
-
 				}
 				else 
 					matrix_->push_back(missing_value);
@@ -100,15 +91,10 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** data)
 			}
 		}
 
-
 		matrix_->multiply(scaling_);
 		matrix_->plus(offset_);
-        
-
-        
-	        matrix_->setMapsAxis();
-        
 
+	    matrix_->setMapsAxis();
 	}
 	catch (MagicsException& e)
 	{
@@ -268,8 +254,5 @@ void NetcdfGeoMatrixInterpretor::customisedPoints(const Transformation& transfor
 		catch (MagicsException& e)
 		{
 			MagLog::error() << e << "\n";
-
 		}
-
-
 }
