@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file ShapeDecoder.cc
     \brief Implementation of the Template class ShapeDecoder.
@@ -291,7 +283,7 @@ void ShapeDecoder::decode(const Transformation& transformation, const string& fi
 /*! \brief Decoder to read land and lakes
  \sa CoastPlotting::decode(const Layout& parent )
 */
-void ShapeDecoder::decode(vector<Polyline>& data, const Transformation& transformation)
+void ShapeDecoder::decode(vector<Polyline*>& data, const Transformation& transformation)
 {
 	Timer timer("Read Shape file ", "read shape file" + path_);
 
@@ -350,21 +342,21 @@ void ShapeDecoder::decode(vector<Polyline>& data, const Transformation& transfor
 				}
 
 				if ( !in && !right && !left ) continue;
-				VectorOfPointers<vector<Polyline *> > polys;
+
 				Polyline* poly = 0;
                 Polyline* polyleft = 0;
                 Polyline* polyright = 0; 
                 if ( in) {
                     poly  = new Polyline();
-                    polys.push_back(poly);
+                    data.push_back(poly);
                 }
 				if ( left ) {
                     polyleft  = new Polyline();
-                    polys.push_back(polyleft);
+                    data.push_back(polyleft);
                 }
                 if ( right ) {
                     polyright  = new Polyline();
-                    polys.push_back(polyright);
+                    data.push_back(polyright);
                 }
                 
 				left = false;
@@ -386,6 +378,7 @@ void ShapeDecoder::decode(vector<Polyline>& data, const Transformation& transfor
 					const double y = psShape->padfY[j];
 
 					if ( iPart==1 ) {
+
 							if ( poly )      poly->push_back(PaperPoint(x, y));
 							if ( polyleft )  polyleft->push_back( PaperPoint(x-360, y));
 							if ( polyright ) polyright->push_back(PaperPoint(x+360, y));
@@ -398,18 +391,21 @@ void ShapeDecoder::decode(vector<Polyline>& data, const Transformation& transfor
 				}
 
 	            /// first we clip
+				/*
                 for (vector<Polyline*>::iterator poly = polys.begin(); poly != polys.end(); ++poly ) {
-                    //(*poly)->sanityCheck();
+                	transformation(**poly, data);
+
                     vector<Polyline> clipped;
                     geobox.intersect(**poly, clipped);
 	                // then we reproject!
                     for (vector<Polyline>::iterator clip = clipped.begin(); clip != clipped.end(); ++clip ) {
                     	clip->reproject(transformation);
-                    	//clip->sanityCheck();
                     	box.intersect(*clip, data);
-                    	//data.push_back(*clip);
-                    }
-                }
+                    	data.push_back(*clip);
+                    }}
+				*/
+
+
 			}
 			SHPDestroyObject(psShape);
 			SHPClose( hSHP );
@@ -419,3 +415,5 @@ void ShapeDecoder::decode(vector<Polyline>& data, const Transformation& transfor
 			MagLog::error() << "Can not open Shapefile " << path_ << endl;
 		}
 }
+
+
