@@ -1,23 +1,13 @@
-/******************************** LICENSE ********************************
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
-
-  Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
-  Licensed under the Apache License, Version 2.0 (the "License");
-  you may not use this file except in compliance with the License.
-  You may obtain a copy of the License at
-
-     http://www.apache.org/licenses/LICENSE-2.0
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-European Centre for Medium-Range Weather Forecasts
-
-
- ******************************** LICENSE ********************************/
 /*
 
  I currently have a function that accepts a cairo context (with a path already set)
@@ -539,8 +529,8 @@ MAGICS_NO_EXPORT void CairoDriver::write_tiff() const
 
     // DPI
     TIFFSetField(tif, TIFFTAG_RESOLUTIONUNIT, RESUNIT_INCH);
-    TIFFSetField(tif, TIFFTAG_XRESOLUTION, (float) 90.;// resolution_);
-    TIFFSetField(tif, TIFFTAG_YRESOLUTION, (float) 90.;// resolution_);
+    TIFFSetField(tif, TIFFTAG_XRESOLUTION, (float) 90.);
+    TIFFSetField(tif, TIFFTAG_YRESOLUTION, (float) 90.);
 
     unsigned char *buf;
     if (TIFFScanlineSize(tif))
@@ -1193,6 +1183,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderText(const Text& text) const
 
 	for(;niceText<niceTextEnd;niceText++)
 	{
+		if ((*niceText).text().empty()) continue;
 		MagFont magfont = (*niceText).font();
 		const std::set<string>& styles = magfont.styles();
 
@@ -1323,9 +1314,12 @@ MAGICS_NO_EXPORT void CairoDriver::circle(const MFloat x, const MFloat y, const
 
 //	cairo_identity_matrix (cr_);
 	cairo_set_line_width (cr_, currentLineWidth_);
-	cairo_set_source_rgba(cr_,currentColour_.red(),currentColour_.green(),currentColour_.blue(),currentColour_.alpha());
-
 	int fill = s;
+	if(fill==10) {
+		cairo_set_line_width (cr_, currentLineWidth_*5);
+		fill=0;
+	}
+	cairo_set_source_rgba(cr_,currentColour_.red(),currentColour_.green(),currentColour_.blue(),currentColour_.alpha());
 
 	//if(s > 8) fill = 8;
 	if( (s > 0) && (fill != 9) )
