@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file Contour.cc
     \brief Implementation of the Template class Contour.
@@ -95,7 +87,10 @@ void Contour::operator()(Data& data, BasicGraphicsObjectContainer& parent)
 		if(library->checkId(needId,needAttributes))
 		{			
     			data.visit(needAttributes);
+
+
     			library->getAttributes(needAttributes,attributes);
+
     			this->set(attributes);
     	}
 		else {
@@ -107,7 +102,10 @@ void Contour::operator()(Data& data, BasicGraphicsObjectContainer& parent)
     data.getReady(parent.transformation());
 
 	MatrixHandler* box =  data.matrix().getReady(parent.transformation());
-
+	if (!box  ){
+		MagLog::error() << "Invalid data for contouring" << endl;
+		return;
+	}
 	if ( !box->rows() ||  !box->columns() ) {
 		(*this->contour_)(data, parent);
 		(*this->grid_)(data, parent);
