@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file Curve.cc
     \brief Implementation of the Template class Curve.
@@ -106,7 +98,7 @@ void Curve::operator()(Data& data, BasicGraphicsObjectContainer& task)
 
 
     std::set<string> needs;
-    CustomisedPointsList points;
+    CustomisedPointsList raw, points;
 
     data.customisedPoints(transformation, needs, points, true);
 
@@ -121,6 +113,10 @@ void Curve::operator()(Data& data, BasicGraphicsObjectContainer& task)
 	
 	CustomisedPointsList::iterator point = points.begin();
 
+	// we clean the list;
+
+
+
     while ( point != points.end() ) {
     	if ( this->missing(**point) ) {
     		++point;
@@ -193,6 +189,7 @@ void Curve::operator()(Data& data, BasicGraphicsObjectContainer& task)
     }
 
     if ( missing.empty() == false ) {
+
     	std::map<string, MissingMethod>::iterator method = missingMethods_.find(lowerCase(missing_mode_));
     	if ( method == missingMethods_.end() )
     	{
@@ -396,6 +393,8 @@ bool Curve::ignore(const PaperPoint&, const PaperPoint&, const vector<PaperPoint
 
 bool Curve::join(const PaperPoint& p1, const PaperPoint& p2, const vector<PaperPoint>& , BasicGraphicsObjectContainer& task)
 {
+	if ( !task.transformation().in(p2) )
+		return true;
 	Polyline* curve  = new Polyline();
 	(*curve).setColour(*missing_colour_);
 	(*curve).setLineStyle(missing_style_);
