@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at
-
- http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file IsoPlot.cc
  \brief Implementation of the Template class IsoPlot.
@@ -1331,7 +1323,7 @@ void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
     double min = data.min();
     double max = data.max();
     (*levelSelection_).clear();
-    (*levelSelection_).calculate(min , max , shading_->shadingMode());
+    (*levelSelection_).calculate(min , max , true);
     (*label_).prepare(*levelSelection_, (*colour_).name());
     return (*shading_)(*levelSelection_);
 }
@@ -1344,8 +1336,15 @@ void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
  void IsoPlot::operator()(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
 {
     prepare(data);
-    if ( legend_only_ ) return;
-
+    if ( legend_only_ ) {
+        if ( rainbow_ ) {
+            rainbowMethod_->set(*this);
+            rainbowMethod_->prepare(*levelSelection_, true);
+            setThicknessAndStyle();
+        }
+        return;
+    }
+    
     {
         Timer timer("contouring", "Time spent in contouring");
         isoline(data, parent);
@@ -1360,7 +1359,7 @@ void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
     vector<Colour>::iterator colour = colours.begin();
 #endif
 
-    (*shading_)(data, parent);
+    (*shading_)(this, data, parent);
     (*highlight_).prepare(*levelSelection_);
 
     if ( rainbow_ ) {
@@ -1417,21 +1416,13 @@ void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
  void NoIsoPlot::operator()(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
 {
     // Create the isolines...
-    if ( !prepare(data) ) {
-        if ( legend_only_ ) return;
-        (*shading_)(data, parent);
-        // do not send the isolines...
-        return;
-    }
+    prepare(data);
+
     if ( legend_only_ ) return;
     // The shading needs the isolines..
-    // WE will calculate them but will not send them to the printer
-    {
-        Timer timer("contouring", "Time spent in contouring");
-        isoline(data, parent);
-    }
 
-    (*shading_)(data, parent);
+
+    (*shading_)(this, data, parent);
 
     // Now we feed the task...
         for (vector<vector<Polyline* >* >::const_iterator lines = lines_.begin(); lines != lines_.end(); ++lines)
@@ -1479,8 +1470,8 @@ void IsoPlot::visit(Data& data, LegendVisitor& legend) {
 
                     line->setColour((*rainbowMethod_)(*level));
                     line->setLineStyle(line_style(*level));
-                    line->setThickness(thickness(*level));
-                    legend.add(new LineEntry(*level, line));
+                    line->setThickness(thickness(*level)*5);
+                    legend.add(new RainbowEntry(*level, line));
                 }
                 break;
             }
