@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file IsoShading.h
     \brief Definition of the Template class IsoShading.
@@ -43,7 +35,7 @@
 namespace magics {
 
 class ContourMethod;
-
+class IsoPlot;
 class NoIsoShading  {
 
 public:
@@ -54,10 +46,10 @@ public:
 	virtual void toxml(ostream&, int = 0) const {}
 	virtual bool accept(const string&) { return true;}
     
-	virtual void operator()(MatrixHandler&, BasicGraphicsObjectContainer&)
+	virtual void operator()(IsoPlot*, MatrixHandler&, BasicGraphicsObjectContainer&)
+			{  }
+	virtual void operator()(Data&, BasicGraphicsObjectContainer&)
 			{  }
-		virtual void operator()(Data&, BasicGraphicsObjectContainer&)
-				{  }
  
     
     virtual NoIsoShading* clone() {
@@ -118,8 +110,8 @@ public:
 	        	    		const Transformation& transformation, int width, int height,
 	        	    		float resolution, const string& technique) {
 		 return technique_->array(matrix, range, transformation, width, height, resolution, technique); }
-	virtual void operator()(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
-		{ (*this->technique_)(data, parent); }
+	virtual void operator()(IsoPlot* iso, MatrixHandler& data, BasicGraphicsObjectContainer& parent)
+		{ (*this->technique_)(iso, data, parent); }
 	virtual void operator()(Data& data, BasicGraphicsObjectContainer& parent)
 			{ (*this->technique_)(data, parent); }
 	virtual int     shadingIndex(double);
