@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file Wind.cc
     \brief Implementation of the Template class Wind.
@@ -60,6 +52,10 @@ void Wind::operator()(Data& data, BasicGraphicsObjectContainer& parent)
 
 	if ( (*type_)(data, parent) )
 		return;
+	if ( type_->legend_only_ )
+		return;
+	
+	
 	ThinningMethod* method=0;
 
 	const Transformation& transformation = parent.transformation();
@@ -90,8 +86,11 @@ void Wind::operator()(Data& data, BasicGraphicsObjectContainer& parent)
 		//request.insert("debug");
 	(*method)(data, transformation, request, points);
 	if (points.empty() )
+
 		return;
-		(*this->type_).prepare(parent, method->units());
+
+	cout << points.size() << "--------------" <<  endl;
+	(*this->type_).prepare(parent, method->units());
 				
 		(*this->type_).adjust(points, transformation);
 
