@@ -1,33 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
-
-
-/*! 
-    \brief Implementation of the Template class SpotDecoder.
-    
-    Magics Team - ECMWF 2005
-    
-    Started: Mon 19-Sep-2005
-    
-    Changes:
-    
-*/
- 
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 #include <locale>
 #include "WrepJSon.h"
@@ -383,6 +362,14 @@ void WrepJSon::eps()
 		double speed = (intensity ==  (values_.values_.end() ) ) ? 0 : intensity->second[i]; 
 		double dir = (direction ==  (values_.values_.end() ) ) ? 0 : direction->second[i]; 
 		CustomisedPoint* point = new CustomisedPoint();		
+
+		DateTime current = base_ + Second(values_.steps_[i] * 3600);
+		(*point)["year"] = current.date().year();
+		(*point)["month"] = current.date().month();
+		(*point)["day"] = current.date().day();
+		(*point)["hours"] = current.time().hours();
+		(*point)["minutes"] = current.time().minutes();
+		(*point)["seconds"] = current.time().seconds();
 		point->longitude(values_.steps_[i] * 3600);		 
 		point->latitude(values_.steps_[i] * 3600);		 
 		(*point)["step"]    = values_.steps_[i] * 3600;
@@ -1321,7 +1308,6 @@ void WrepJSon::visit(TextVisitor& text)
 	}
 
 
-
 	text.update("json", "full_temperature_correction_info", full_correction.str());
 	text.update("json", "short_temperature_correction_info", short_correction.str());
 	text.update("json", "parameter_info", (param_info_ == "none") ? "": param_info_ );
